import React from "react";
import BooleanTypeIcon from "../icons/columntypes/BooleanTypeIcon";
import NumberTypeIcon from "../icons/columntypes/NumberTypeIcon";
import StringTypeIcon from "../icons/columntypes/StringTypeIcon";
import TimedeltaTypeIcon from "../icons/columntypes/TimedeltaTypeIcon";
import DatetimeTypeIcon from "../icons/columntypes/DatetimeTypeIcon";
import { getWidthData } from "./widthUtils";
export const isNumberInRangeInclusive = (num, start, end) => {
    return start <= num && num <= end;
};
/*
    A helper function for getting the first non-null or undefined
    value from a list of arguments.

    NOTE: May cause issues with all null or undefined values
*/
export function firstNonNullOrUndefined(...args) {
    for (let i = 0; i < args.length; i++) {
        const arg = args[i];
        if (arg !== null && arg !== undefined) {
            return arg;
        }
    }
    // NOTE: make sure one of the options is null or undefined
    return args[0];
}
/**
 * Get the grid state of a sheet that was just rendered/switched to.
 */
export const getDefaultGridState = (sheetData, selectedSheetIndex) => {
    return {
        sheetIndex: selectedSheetIndex,
        viewport: {
            width: 0,
            height: 0,
        },
        scrollPosition: {
            scrollLeft: 0,
            scrollTop: 0
        },
        selection: {
            startingColumnIndex: 0,
            endingColumnIndex: 0,
            startingRowIndex: -1,
            endingRowIndex: -1
        },
        widthData: getWidthData(sheetData),
        columnIDsArray: (sheetData === null || sheetData === void 0 ? void 0 : sheetData.data.map(c => c.columnID)) || []
    };
};
// Returns an icon for that type of column
export const getTypeIcon = (mitoType) => {
    if (mitoType === "string_series" /* STRING_SERIES */) {
        return React.createElement(StringTypeIcon, null);
    }
    else if (mitoType === "number_series" /* NUMBER_SERIES */) {
        return React.createElement(NumberTypeIcon, null);
    }
    else if (mitoType === "datetime_series" /* DATETIME_SERIES */) {
        return React.createElement(DatetimeTypeIcon, null);
    }
    else if (mitoType === "timedelta_series" /* TIMEDELTA_SERIES */) {
        return React.createElement(TimedeltaTypeIcon, null);
    }
    else if (mitoType === "boolean_series" /* BOOLEAN_SERIES */) {
        return React.createElement(BooleanTypeIcon, null);
    }
    else {
        // If we can't identify the column, mark it as an object
        return React.createElement(StringTypeIcon, null);
    }
};
/**
 * A helper function to get data describing a cell from
 * indexes, in a type safe way.
 */
export const getCellDataFromCellIndexes = (sheetData, rowIndex, columnIndex) => {
    var _a, _b;
    const columnID = (_a = sheetData === null || sheetData === void 0 ? void 0 : sheetData.data[columnIndex]) === null || _a === void 0 ? void 0 : _a.columnID;
    const columnHeader = (_b = sheetData === null || sheetData === void 0 ? void 0 : sheetData.data[columnIndex]) === null || _b === void 0 ? void 0 : _b.columnHeader;
    const columnFormula = columnID !== undefined ? sheetData === null || sheetData === void 0 ? void 0 : sheetData.columnSpreadsheetCodeMap[columnID] : undefined;
    const columnMitoType = columnID !== undefined ? sheetData === null || sheetData === void 0 ? void 0 : sheetData.columnMitoTypeMap[columnID] : undefined;
    const columnFilters = columnID !== undefined ? sheetData === null || sheetData === void 0 ? void 0 : sheetData.columnFiltersMap[columnID] : undefined;
    const cellValue = columnID !== undefined ? sheetData === null || sheetData === void 0 ? void 0 : sheetData.data[columnIndex].columnData[rowIndex] : undefined;
    return {
        columnID: columnID,
        columnHeader: columnHeader,
        columnFormula: columnFormula,
        columnMitoType: columnMitoType,
        columnFilters: columnFilters,
        cellValue: cellValue,
    };
};
//# sourceMappingURL=utils.js.map